TlsConfig class

TLS configuration

Constructors

TlsConfig({bool rejectUnauthorized = true, String? caCertPem, String? caCertPath, String? clientCertPem, String? clientCertPath, String? clientKeyPem, String? clientKeyPath, String? tlsSniOverride, String? minTlsVersion, List<String>? pinSha256})
const

Properties

caCertPath → String?
final
caCertPem → String?
final
clientCertPath → String?
final
clientCertPem → String?
final
clientKeyPath → String?
final
clientKeyPem → String?
final
hashCode → int
The hash code for this object.
no setterinherited
minTlsVersion → String?
final
pinSha256 → List<String>?
final
rejectUnauthorized → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tlsSniOverride → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited